shelvedump
=======

Simple script to output the contents of a Python `shelve`_ database.
Works on Python 2 and 3.

.. _shelve: http://docs.python.org/2/library/shelve.html


Usage
-----

::

    $ pip install shelvedump
    $ shelvedump shelvedbfile